build_provider_tool_schemas

Function build_provider_tool_schemas 

pub fn build_provider_tool_schemas(
    tools: &[&'static ToolDefinition],
) -> ProviderToolSchemas
Build provider tool schemas for a set of tool definitions.

Note: We intentionally only include schemas for tools that have a well- defined structured interface in gestura-core’s pipeline.