pub fn build_provider_tool_schemas(
tools: &[&'static ToolDefinition],
) -> ProviderToolSchemasExpand description
Build provider tool schemas for a set of tool definitions.
Note: We intentionally only include schemas for tools that have a well-
defined structured interface in gestura-core’s pipeline.